#
# Licensed Materials - Property of IBM
# Rational ClearQuest
# (C) Copyright IBM Corp. 2010.  All Rights Reserved
# US Government Users Restricted Rights
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp
#
# WebSphere script to add ClearQuest environment variables to the target WebSphere profile on
# UNIX platforms.

import os, sys, java, string

def isunix():
    os_name = java.lang.System.getProperty('os.name')
    os_name = os_name.lower()
    print "OS: " + os_name
    return os_name.find('windows') < 0


def add_cq_envs_to_was_server(adminConfig):

    if not isunix():
        print "not unix skipping env set"
        return 

    print "Setting WAS CQ envs"

    clearquest = r"/opt/rational/clearquest/bin/clearquest"
    tempfile = r".cq-output-tempfile.txt"

    print "ClearQuest: " + clearquest

    command = '"%s" -dumpsh > "%s"' % (clearquest, tempfile) 

    os.system(command)

    input = open(tempfile, 'r')
    Lines = input.readlines()
    input.close()

    cqenvs = {}

    for l in Lines:
        # skip over export lines.  Don't care about them
        if l.startswith("export"): continue
        parts = l.split("=")
        value = parts[1]
        # strip off the begining "'" and the trailing "';\n"
        value = value[1:-3]
        cqenvs[ parts[0] ] = value

    os.remove(tempfile)

    serverid = adminConfig.getid('/Server:server1/JavaProcessDef:/')
    server = adminConfig.list('JavaProcessDef', serverid)

    config_was_env = adminConfig.showAttribute(server, 'environment')

    config_was_env = config_was_env[1:-1]
    existing_was_envs = config_was_env.split(' ')

    # if env entries already exist then update them
    for was_env in existing_was_envs:
        if len(was_env) == 0: continue
        name = adminConfig.showAttribute(was_env, 'name')
        if cqenvs.has_key(name):
            print "Modify: " + name
            adminConfig.modify(was_env, [['value', cqenvs[ name ]]])
            del cqenvs[ name ]

    # add any missing envs
    for key in cqenvs.keys():
        print "Add: " + key
        value = [ ['name', key], ['value', cqenvs[key]] ]
        adminConfig.create('Property', server, value, 'environment') 

    adminConfig.save()


#----------------------------------------------------------------
# Main - This will only execute if AdminConfig is intialized.  
# AdminConfig is initialized if the script is launched using wasadmin
#-----------------------------------------------------------------
try:
	AdminConfig
except NameError:
	AdminConfig = None
 
if AdminConfig is not None:
	add_cq_envs_to_was_server(AdminConfig)

